@@ -8,9 +8,10 @@ from api.handler.IHandler import IHandler
 from api.handler.IKillable import IKillable
 from api.handler.ILogAbleHandler import ILogAbleHandler
 from api.handler.IProgressAble import IProgressAble
+from api.handler.IRevoke import IRevoke
 
 
-class ITaskHandler(ILogAbleHandler, IHandler, IKillable, IProgressAble):
+class ITaskHandler(ILogAbleHandler, IHandler, IKillable, IProgressAble, IRevoke):
 
     @abstractmethod
     def execute(self, params):
