@@ -2,13 +2,14 @@ from abc import abstractmethod
 
 from api.handler import HandlerEnum
 from api.handler.IHandler import IHandler
+from api.handler.IRevoke import IRevoke
 from api.handler.script.ICacheAbleScript import ICacheAbleScript
 from api.handler.IKillable import IKillable
 from api.handler.ILogAbleHandler import ILogAbleHandler
 from api.handler.script.IProgressAbleScript import IProgressAbleScript
 
 
-class ISimpleScriptCrawl(IKillable, ILogAbleHandler, ICacheAbleScript, IHandler, IProgressAbleScript):
+class ISimpleScriptCrawl(IKillable, ILogAbleHandler, ICacheAbleScript, IHandler, IProgressAbleScript, IRevoke):
     """
     Python脚本式的Crawl的基类
     """
