@@ -143,6 +143,22 @@ def init_profile_from_environ_property():
         config.spring_profiles_active = environs["SPRING_PROFILES_ACTIVE"]
         log.info(f"从系统环境变量中获取到SPRING_PROFILES_ACTIVE:{config.spring_profiles_active}")
 
+    if "WORK_ON_K8S" in environs:
+        config.work_on_k8s = bool(environs["WORK_ON_K8S"])
+        log.info(f"从系统环境变量中获取到WORK_ON_K8S:{config.work_on_k8s}")
+
+    if "K8S_CONFIG_SERVER_SERVICE" in environs:
+        config.k8s_config_server_service = environs["K8S_CONFIG_SERVER_SERVICE"]
+        log.info(f"从系统环境变量中获取到K8S_CONFIG_SERVER_SERVICE:{config.k8s_config_server_service}")
+
+    if "K8S_FICUS_SERVER_SERVICE" in environs:
+        config.k8s_ficus_server_service = environs["K8S_FICUS_SERVER_SERVICE"]
+        log.info(f"从系统环境变量中获取到K8S_FICUS_SERVER_SERVICE:{config.k8s_ficus_server_service}")
+
+    if "K8S_SCHEDULE_SERVER_SERVICE" in environs:
+        config.k8s_schedule_server_service = environs["K8S_SCHEDULE_SERVER_SERVICE"]
+        log.info(f"从系统环境变量中获取到K8S_SCHEDULE_SERVER_SERVICE:{config.k8s_schedule_server_service}")
+
 
 def init_from_environ_property():
     import os
