@@ -119,7 +119,7 @@ class CeleryProcess(Process):  # 继承Process类
         import uuid
         argv = [
             'worker',
-            '--loglevel=INFO',
+            '--loglevel=DEBUG',
             f'--hostname={config.actor_name}@{uuid.uuid4()}'
         ]
         import cloudcelery
