@@ -132,9 +132,12 @@ def do_finish(job_id: int, task_log_id: int, accept_type: AcceptType = AcceptTyp
         # 需要重新实例化
         task_handler = TaskHandlerContext.load_task_handler(task_param.actorHandler)
 
-    # 有可能是脚本类型的异步任务，尝试加载一下
-    if task_handler is None:
-        task_handler = load_async_script_task_handler()
+    # 脚本类型的异步任务
+    if task_handler is None and task_param.jobType == "PYTHON":
+        from api.handler.script import ScriptPythonFactory
+        instance = ScriptPythonFactory.load_instance(f"ScriptPython{task_param.jobId}", task_param.scriptJobSource, "IHandler")
+        task_handler = ScriptPythonTaskHandler(task_param.jobId, task_param.updateTime, task_param.scriptJobSource)
+        task_handler.current_task = instance
 
     if task_thread is None:
         task_thread = TaskThreadHolder.registry_task_thread(job_id, task_handler, "异步任务构造taskThread")
@@ -156,6 +159,8 @@ def do_finish(job_id: int, task_log_id: int, accept_type: AcceptType = AcceptTyp
             response_data = Munch({'response:': data})
     headers = dict(request.headers)
     async_service_response = task_handler.transform_response(response_data, headers)
+    if async_service_response is None:
+        raise ServiceInnerException(f"任务:{task_log_id}转换异步结果为空,无法回调")
 
     # 异步执行结果回调
     t = Thread(target=async_do_finish, args=(
@@ -167,34 +172,3 @@ def do_finish(job_id: int, task_log_id: int, accept_type: AcceptType = AcceptTyp
 @remote.route('/async/response/<int:job_id>/<int:task_log_id>/plain', methods=['POST'])
 def do_finish_from_plain(job_id: int, task_log_id: int):
     return do_finish(job_id, task_log_id, AcceptType.TEXT_PLAIN)
-
-def load_async_script_task_handler():
-    from config.annotation import Value
-    from api.handler.script import ScriptPythonFactory
-
-    @Value("${actor.name:unknown}")
-    def actor_name():
-        pass
-
-    # region 过滤函数
-    def filter_job(item) -> bool:
-        if item.jobType == "PYTHON" and item.scriptJobSource is not None and len(item.scriptJobSource) > 0:
-            return True
-        return False
-
-    jobs = JobScheduleClient.get_jobs(actor_name())
-    if jobs is None or len(jobs) == 0:
-        return None
-
-    jobs = list(filter(filter_job, jobs))
-    if jobs is None or len(jobs) == 0:
-        return None
-
-    # 实例化Handler
-    job_info = jobs.pop(0);
-    script_task_handler:ScriptPythonTaskHandler = ScriptPythonTaskHandler(job_info.id, job_info.updateTime, job_info.scriptJobSource)
-    instance = ScriptPythonFactory.load_instance(f"ScriptPython{job_info.id}", job_info.scriptJobSource, "IHandler")
-    script_task_handler.current_task = instance
-
-    return script_task_handler
-
