@@ -43,11 +43,16 @@ def callback_revoke(log_id):
 
     # 这里就根据task_id去查询 log_id,job_id, task_handler
     from client import ScheduleJobTaskLogClient
+    from api.handler.ICacheAbleHandler import CacheAbleHandlerHolder
     task_log = ScheduleJobTaskLogClient.get_task_log_by_id(log_id)
 
     # 这说明有这个方法了
     try:
         actorParam = Munch(json.loads(task_log.actorParam))
+        # 设置缓存需要的key
+        CacheAbleHandlerHolder.get_handler().set_local_code(actorParam["site_"] + "_" + actorParam["projectCode_"] + "_" + actorParam["code_"])
+        CacheAbleHandlerHolder.get_handler().set_process_id(actorParam.get("__processLogId__"))
+
         revoke_handler(task_log.actorCode, task_log.actorHandler, actorParam["code_"],
                        actorParam["projectCode_"], actorParam["site_"], task_log.id, task_log.jobId,
                        task_log.messageId, False)
